@@ -17,10 +17,13 @@ def clean(force: bool) -> None:
         images_list = client.images(filters={"label": "maintainer=Raiyan Yahya <raiyanyahyadeveloper@gmail.com>"})
         for image in images_list:
             client.remove_image(image=image['Id'], force=force)
+        custom_images = client.images(filters={"label": "maintainer=Custom Environment"})
+        for custom_image in custom_images:
+            client.remove_image(image=custom_image['Id'], force=force)
         print(":boom: freshenv flavours and environments removed.")
     except errors.APIError as e:
         if e.status_code == 409:
-            print(":runner: Found a [bold green]running[/bold green] environment. Close the session first or use the [bold blue]--force[/bold blue] flag.")
+            print(":runner: Found a [bold green]running[/bold green] environment or a referenced flavour. Close the session first or use the [bold blue]--force[/bold blue] flag.")
         else:
             raise Exception(e)
     except errors.DockerException:
