@@ -1,5 +1,6 @@
 import click
 from freshenv import provision, view, start, remove, check, clean, flavours, build
+from freshenv.cloud import cloud
 
 
 @click.group()
@@ -15,4 +16,5 @@ cli.add_command(remove.remove)
 cli.add_command(check.check)
 cli.add_command(clean.clean)
 cli.add_command(flavours.flavours)
-cli.add_command(build.build)
\ No newline at end of file
+cli.add_command(build.build)
+cli.add_command(cloud.cloud)
\ No newline at end of file
